@@ -9,48 +9,32 @@
 #include <config.h>
 #include <string.h>
 #include <signal.h>
+#include <unistd.h>
 #include <libgnome/libgnome.h>
 #include <libbonobo.h>
 #include <gdk/gdkx.h>
 
-#include "basep-widget.h"
 #include "button-widget.h"
 #include "drawer.h"
 #include "launcher.h"
 #include "menu-util.h"
 #include "menu.h"
-#include "panel-config.h"
 #include "panel-gconf.h"
 #include "panel-config-global.h"
-#include "session.h"
 #include "panel-applet-frame.h"
 #include "egg-screen-exec.h"
 #include "panel-action-button.h"
+#include "panel-menu-bar.h"
+#include "panel-compatibility.h"
+#include "panel-toplevel.h"
+#include "panel-util.h"
+#include "panel-profile.h"
+#include "panel-menu-button.h"
+#include "panel-globals.h"
 
 #define SMALL_ICON_SIZE 20
 
-extern GSList *panels;
-
-GSList *applets = NULL;
-int applet_count = 0;
-
-/*config sync stuff*/
-extern int applets_to_sync;
-extern int need_complete_save;
-
-extern gboolean commie_mode;
-extern GlobalConfig global_config;
-
-static GConfEnumStringPair object_type_enum_map [] = {
-	{ APPLET_DRAWER,   "drawer-object" },
-	{ APPLET_MENU,     "menu-object" },
-	{ APPLET_LAUNCHER, "launcher-object" }, 
-	{ APPLET_BONOBO,   "bonobo-applet" },
-	{ APPLET_ACTION,   "action-applet" },
-	{ APPLET_LOCK,     "lock-object" },   /* FIXME:                           */
-	{ APPLET_LOGOUT,   "logout-object" }, /*   Both only for backwards compat */
-};
-
+static GSList *registered_applets = NULL;
 static GSList *queued_position_saves = NULL;
 static guint   queued_position_source = 0;
 
@@ -67,82 +51,29 @@ move_applet_callback (GtkWidget *widget, AppletInfo *info)
 	panel = PANEL_WIDGET (info->widget->parent);
 
 	panel_widget_applet_drag_start (panel, info->widget,
-					PW_DRAG_OFF_CENTER);
-}
-
-void
-panel_applet_clean_gconf (AppletType  type,
-			  const char *gconf_key,
-			  gboolean    clean_gconf)
-{
-	GConfClient *client;
-	GSList      *id_list, *l;
-	const char  *temp_key = NULL;
-	const char  *profile;
-
-	g_return_if_fail (gconf_key != NULL);
-
-	client  = panel_gconf_get_client ();
-	profile = panel_gconf_get_profile ();
-
-	if (type == APPLET_BONOBO)
-		temp_key = panel_gconf_general_key (profile, "applet_id_list");
-	else
-		temp_key = panel_gconf_general_key (profile, "object_id_list");
-
-        id_list = gconf_client_get_list (
-			panel_gconf_get_client (), temp_key,
-			GCONF_VALUE_STRING, NULL);
-
-        for (l = id_list; l; l = l->next)
-                if (strcmp (gconf_key, (char *) l->data) == 0)
-                        break;
-
-        if (l) {
-		g_free (l->data);
-		l->data = NULL;
-                id_list = g_slist_delete_link (id_list, l);
-
-                gconf_client_set_list (client, temp_key, GCONF_VALUE_STRING, id_list, NULL);
-
-		if (type == APPLET_BONOBO)
-			temp_key = panel_gconf_sprintf (
-					"/apps/panel/profiles/%s/applets/%s",
-					profile, gconf_key);
-		else
-			temp_key = panel_gconf_sprintf (
-					"/apps/panel/profiles/%s/objects/%s",
-					profile, gconf_key);
-
-		if (clean_gconf)
-			panel_gconf_clean_dir (client, temp_key);
-        }
-
-	panel_g_slist_deep_free (id_list);
+					PW_DRAG_OFF_CENTER,
+					GDK_CURRENT_TIME);
 }
 
 /* permanently remove an applet - all non-permanent
  * cleanups should go in panel_applet_destroy()
  */
 void
-panel_applet_clean (AppletInfo *info,
-		    gboolean    clean_gconf)
+panel_applet_clean (AppletInfo *info)
 {
 	g_return_if_fail (info != NULL);
 
-	if (info->type == APPLET_LAUNCHER) {
-		Launcher    *launcher = info->data;
-		const gchar *location;
-
-		location = gnome_desktop_item_get_location (launcher->ditem);
-
-		/* Launcher may not yet have been hoarded */
-		if (location)
-			session_add_dead_launcher (location);
+	switch (info->type) {
+	case PANEL_OBJECT_LAUNCHER:
+		panel_launcher_delete (info->data);
+		break;
+	case PANEL_OBJECT_DRAWER:
+		panel_drawer_delete (info->data);
+		break;
+	default:
+		break;
 	}
 
-	panel_applet_clean_gconf (info->type, info->gconf_key, clean_gconf);
-
 	if (info->widget) {
 		GtkWidget *widget = info->widget;
 
@@ -151,42 +82,21 @@ panel_applet_clean (AppletInfo *info,
 	}
 }
 
-static gboolean
-applet_idle_remove (gpointer data)
-{
-	AppletInfo *info = data;
-
-	info->remove_idle = 0;
-
-	if (info->type == APPLET_DRAWER) {
-		Drawer *drawer = (Drawer *) info->data;
-
-		panel_delete (PANEL_WIDGET (BASEP_WIDGET (drawer->drawer)->panel));
-	} else
-		panel_applet_clean (info, TRUE);
-
-	return FALSE;
-}
-
-void
-panel_applet_remove_in_idle (AppletInfo *info)
-{
-	if (info->remove_idle == 0)
-		info->remove_idle = g_idle_add (applet_idle_remove, info);
-}
-
 static void
 applet_remove_callback (GtkWidget  *widget,
 			AppletInfo *info)
 {
-	panel_applet_remove_in_idle (info);
+	panel_profile_delete_object (info);
 }
 
 static inline GdkScreen *
 applet_user_menu_get_screen (AppletUserMenu *menu)
 {
-	return gtk_window_get_screen (
-			GTK_WINDOW (get_panel_parent (menu->info->widget)));
+	PanelWidget *panel_widget;
+
+	panel_widget = PANEL_WIDGET (menu->info->widget->parent);
+
+	return gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel));
 }
 
 static void
@@ -200,7 +110,7 @@ applet_callback_callback (GtkWidget      *widget,
 	screen = applet_user_menu_get_screen (menu);
 
 	switch (menu->info->type) {
-	case APPLET_LAUNCHER:
+	case PANEL_OBJECT_LAUNCHER:
 		if (!strcmp (menu->name, "properties"))
 			launcher_properties (
 				menu->info->data, screen);
@@ -211,26 +121,33 @@ applet_callback_callback (GtkWidget      *widget,
 		else if (!strcmp (menu->name, "help_on_app"))
 			launcher_show_help (menu->info->data, screen);
 		break;
-	case APPLET_DRAWER: 
+	case PANEL_OBJECT_DRAWER: 
 		if (strcmp (menu->name, "properties")==0) {
 			Drawer *drawer = menu->info->data;
 			g_assert(drawer);
-			panel_config(drawer->drawer);
+#ifdef FIXME_FOR_NEW_CONFIG
+			panel_config (drawer->toplevel);
+#endif
 		} else if (strcmp (menu->name, "help") == 0) {
 			panel_show_help (screen, "wgospanel.xml", "gospanel-18");
 		}
 		break;
-	case APPLET_MENU:
-		if (!strcmp (menu->name, "help"))
-			panel_show_help (screen, "wgospanel.xml", "gospanel-37");
+	case PANEL_OBJECT_MENU:
+		panel_menu_button_invoke_menu (
+			PANEL_MENU_BUTTON (menu->info->widget), menu->name);
 		break;
-	case APPLET_ACTION:
-	case APPLET_LOGOUT:
-	case APPLET_LOCK:
+	case PANEL_OBJECT_ACTION:
+	case PANEL_OBJECT_LOGOUT:
+	case PANEL_OBJECT_LOCK:
 		panel_action_button_invoke_menu (
 			PANEL_ACTION_BUTTON (menu->info->widget), menu->name);
 		break;
-	case APPLET_BONOBO:
+	case PANEL_OBJECT_MENU_BAR:
+		panel_menu_bar_invoke_menu (
+			PANEL_MENU_BAR (menu->info->widget), menu->name);
+		break;
+
+	case PANEL_OBJECT_BONOBO:
 		/*
 		 * Applet's menu's are handled differently
 		 */
@@ -242,13 +159,13 @@ applet_callback_callback (GtkWidget      *widget,
 }
 
 static void
-applet_menu_deactivate(GtkWidget *w, AppletInfo *info)
+applet_menu_deactivate (GtkWidget *w, AppletInfo *info)
 {
-	GtkWidget *panel = get_panel_parent(info->widget);
-	info->menu_age = 0;
-	
-	if(BASEP_IS_WIDGET(panel))
-		BASEP_WIDGET(panel)->autohide_inhibit = FALSE;
+	PanelWidget *panel_widget;
+
+	panel_widget = PANEL_WIDGET (info->widget->parent);
+
+	panel_toplevel_unblock_auto_hide (panel_widget->toplevel);
 }
 
 AppletUserMenu *
@@ -307,7 +224,6 @@ panel_applet_add_callback (AppletInfo *info,
 		}
 		gtk_widget_unref(info->menu);
 		info->menu = NULL;
-		info->menu_age = 0;
 	}
 }
 
@@ -342,7 +258,6 @@ panel_applet_remove_callback (AppletInfo *info,
 		}
 		gtk_widget_unref (info->menu);
 		info->menu = NULL;
-		info->menu_age = 0;
 	}
 }
 
@@ -544,30 +459,25 @@ static void
 applet_show_menu (AppletInfo     *info,
 		  GdkEventButton *event)
 {
-	GtkWidget *panel;
+	PanelWidget *panel_widget;
 
 	g_return_if_fail (info != NULL);
 
-	panel = get_panel_parent (info->widget);
+	panel_widget = PANEL_WIDGET (info->widget->parent);
 
 	if (!info->menu)
 		info->menu = panel_applet_create_menu (info);
 
 	g_assert (info->menu);
 
-	if (BASEP_IS_WIDGET (panel)) {
-		BASEP_WIDGET (panel)->autohide_inhibit = TRUE;
-		basep_widget_queue_autohide (BASEP_WIDGET (panel));
-	}
-
-	info->menu_age = 0;
+	panel_toplevel_block_auto_hide (panel_widget->toplevel);
 
 	panel_applet_menu_set_recurse (GTK_MENU (info->menu),
 				       "menu_panel",
 				       info->widget->parent);
 
 	gtk_menu_set_screen (GTK_MENU (info->menu),
-			     panel_screen_from_toplevel (panel));
+			     gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel)));
 
 	if (!GTK_WIDGET_REALIZED (info->menu))
 		gtk_widget_show (info->menu);
@@ -586,10 +496,10 @@ applet_do_popup_menu (GtkWidget      *widget,
 		      GdkEventButton *event,
 		      AppletInfo     *info)
 {
-	if (panel_applet_in_drag)
+	if (panel_applet_is_in_drag ())
 		return FALSE;
 
-	if (info->type == APPLET_BONOBO)
+	if (info->type == PANEL_OBJECT_BONOBO)
 		return FALSE;
 
 	applet_show_menu (info, event);
@@ -630,24 +540,23 @@ panel_applet_destroy (GtkWidget  *widget,
 
 	info->widget = NULL;
 
-	applets = g_slist_remove (applets, info);
+	registered_applets = g_slist_remove (registered_applets, info);
 
 	queued_position_saves =
 		g_slist_remove (queued_position_saves, info);
 
-	if (info->remove_idle) {
-		g_source_remove (info->remove_idle);
-		info->remove_idle = 0;
-	}
-
-	if (info->type == APPLET_DRAWER) {
+	if (info->type == PANEL_OBJECT_DRAWER) {
 		Drawer *drawer = info->data;
 
-		if (drawer->drawer) {
-			PANEL_WIDGET (BASEP_WIDGET (drawer->drawer)->panel)->master_widget = NULL;
+		if (drawer->toplevel) {
+			PanelWidget *panel_widget;
 
-			gtk_widget_destroy (drawer->drawer);
-			drawer->drawer = NULL;
+			panel_widget = panel_toplevel_get_panel_widget (
+							drawer->toplevel);
+			panel_widget->master_widget = NULL;
+
+			gtk_widget_destroy (GTK_WIDGET (drawer->toplevel));
+			drawer->toplevel = NULL;
 		}
 	}
 
@@ -672,32 +581,30 @@ panel_applet_destroy (GtkWidget  *widget,
 	g_list_free (info->user_menu);
 	info->user_menu = NULL;
 
-	g_free (info->gconf_key);
-	info->gconf_key = NULL;
+	g_free (info->id);
+	info->id = NULL;
 
 	g_free (info);
 }
 
 typedef struct {
-	AppletType   type;
-	PanelWidget *panel_widget;
-	int          position;
-	char        *unique_id;
-	gulong       destroy_handler;
+	char            *id;
+	PanelObjectType  type;
+	char            *toplevel_id;
+	int              position;
+	guint            right_stick : 1;
 } PanelAppletToLoad;
 
 static GSList *panel_applets_to_load = NULL;
 
 static void
-whack_applet_to_load (PanelAppletToLoad *applet)
+free_applet_to_load (PanelAppletToLoad *applet)
 {
-	if (applet->destroy_handler > 0)
-		g_signal_handler_disconnect (applet->panel_widget,
-					     applet->destroy_handler);
-	applet->destroy_handler = 0;
+	g_free (applet->id);
+	applet->id = NULL;
 
-	g_free (applet->unique_id);
-	applet->unique_id = NULL;
+	g_free (applet->toplevel_id);
+	applet->toplevel_id = NULL;
 
 	g_free (applet);
 }
@@ -705,188 +612,133 @@ whack_applet_to_load (PanelAppletToLoad *applet)
 static gboolean
 panel_applet_load_idle_handler (gpointer dummy)
 {
-	PanelAppletToLoad *applet;
+	PanelAppletToLoad *applet = NULL;
+	PanelToplevel     *toplevel = NULL;
+	PanelWidget       *panel_widget;
+	GSList            *l;
 
-	if (panel_applets_to_load == NULL)
+	if (!panel_applets_to_load)
 		return FALSE;
 
-	applet = (PanelAppletToLoad *) panel_applets_to_load->data;
-	panel_applets_to_load->data = NULL;
-	panel_applets_to_load =
-		g_slist_delete_link (panel_applets_to_load,
-				     panel_applets_to_load);
+	for (l = panel_applets_to_load; l; l = l->next) {
+		applet = l->data;
+
+		toplevel = panel_profile_get_toplevel_by_id (applet->toplevel_id);
+		if (toplevel)
+			break;
+	}
+
+	if (!l) {
+		/* All the rest of the applets don't have a panel */
+		for (l = panel_applets_to_load; l; l = l->next)
+			free_applet_to_load (l->data);
+		g_slist_free (panel_applets_to_load);
+		panel_applets_to_load = NULL;
+		return FALSE;
+	}
+
+	panel_applets_to_load = g_slist_delete_link (panel_applets_to_load, l);
+
+	panel_widget = panel_toplevel_get_panel_widget (toplevel);
+
+	if (applet->right_stick && !panel_widget->packed)
+		applet->position = panel_widget->size - applet->position;
 
 	switch (applet->type) {
-	case APPLET_BONOBO:
+	case PANEL_OBJECT_BONOBO:
 		panel_applet_frame_load_from_gconf (
-					applet->panel_widget,
+					panel_widget,
 					applet->position,
-					applet->unique_id);
+					applet->id);
 		break;
-	case APPLET_DRAWER:
-		drawer_load_from_gconf (applet->panel_widget,
+	case PANEL_OBJECT_DRAWER:
+		drawer_load_from_gconf (panel_widget,
 					applet->position,
-					applet->unique_id);
+					applet->id);
 		break;
-	case APPLET_MENU:
-		menu_load_from_gconf (applet->panel_widget,
-				      applet->position,
-				      applet->unique_id);
+	case PANEL_OBJECT_MENU:
+		panel_menu_button_load_from_gconf (panel_widget,
+						   applet->position,
+						   TRUE,
+						   applet->id);
 		break;
-	case APPLET_LAUNCHER:
-		launcher_load_from_gconf (applet->panel_widget,
+	case PANEL_OBJECT_LAUNCHER:
+		launcher_load_from_gconf (panel_widget,
 					  applet->position,
-					  applet->unique_id);
+					  applet->id);
 		break;
-	case APPLET_LOGOUT:  /* FIXME: This is backward compatibility only. */
-	case APPLET_LOCK:    /*        Remove at some time in the future    */
-		panel_action_button_load (
-				applet->type == APPLET_LOGOUT ? PANEL_ACTION_LOGOUT :
-								PANEL_ACTION_LOCK,
-				applet->panel_widget,
+	case PANEL_OBJECT_LOGOUT:
+	case PANEL_OBJECT_LOCK:
+		panel_action_button_load_compatible (
+				applet->type,
+				panel_widget,
 				applet->position,
 				TRUE,
-				applet->unique_id,
-				TRUE);
+				applet->id);
 		break;
-	case APPLET_ACTION:
+	case PANEL_OBJECT_ACTION:
 		panel_action_button_load_from_gconf (
-				applet->panel_widget,
+				panel_widget,
 				applet->position,
 				TRUE,
-				applet->unique_id);
+				applet->id);
+		break;
+	case PANEL_OBJECT_MENU_BAR:
+		panel_menu_bar_load_from_gconf (
+				panel_widget,
+				applet->position,
+				TRUE,
+				applet->id);
+		break;
 	default:
 		break;
 	}
 
-	whack_applet_to_load (applet);
+	free_applet_to_load (applet);
 
 	return TRUE;
 }
 
-static void
-panel_destroyed_while_loading (GtkWidget *panel, gpointer data)
-{
-	PanelAppletToLoad *applet = data;
-
-	applet->destroy_handler = 0;
-
-	panel_applets_to_load =
-		g_slist_remove (panel_applets_to_load, applet);
-
-	whack_applet_to_load (applet);
-}
-
-static void
-panel_applet_load_from_unique_id (PanelGConfKeyType  type,
-				  GConfClient       *gconf_client,
-				  const char        *profile,
-				  const char        *unique_id)
+void
+panel_applet_queue_applet_to_load (char            *id,
+				   PanelObjectType  type,
+				   char            *toplevel_id,
+				   int              position,
+				   gboolean         right_stick)
 {
 	PanelAppletToLoad *applet;
-	PanelWidget       *panel_widget;
-	AppletType         applet_type = 0;
-	const char        *temp_key;
-	char              *type_string;
-	char              *panel_id;
-	int                position;
-	gboolean           right_stick;
 
-	temp_key = panel_gconf_full_key (type, profile, unique_id, "object_type");
-	type_string = gconf_client_get_string (gconf_client, temp_key, NULL);
-	if (!type_string) {
-		g_printerr (_("No object_type set for panel object with ID %s\n"), unique_id);
+	if (!toplevel_id) {
+		g_warning ("No toplevel on which to load object '%s'\n", id);
 		return;
 	}
-        
-	if (!gconf_string_to_enum (object_type_enum_map,
-				   type_string,
-				   (int *) &applet_type)) {
-		g_free (type_string);
-		g_warning ("Unkown applet type %s from %s", type_string, temp_key);
-		return;
-	}
-	
-	g_free (type_string);
-
-	temp_key = panel_gconf_full_key (type, profile, unique_id, "position");
-	position = gconf_client_get_int (gconf_client, temp_key, NULL);
-	
-	temp_key = panel_gconf_full_key (type, profile, unique_id, "panel_id");
-	panel_id = gconf_client_get_string (gconf_client, temp_key, NULL);
-	if (!panel_id) {
-		g_printerr (_("No panel_id set for panel object with ID %s\n"), unique_id);
-		return;
-	}
-
-	temp_key = panel_gconf_full_key (type, profile, unique_id, "panel_right_stick");
-	right_stick = gconf_client_get_bool (gconf_client, temp_key, NULL);
-
-	panel_widget = panel_widget_get_by_id (panel_id);
-	g_free (panel_id);
-
-	if (!panel_widget)
-		return;
-
-	if (right_stick && !panel_widget->packed)
-		position = panel_widget->size - position;
 
 	applet = g_new0 (PanelAppletToLoad, 1);
 
-	applet->type            = applet_type;
-	applet->panel_widget    = panel_widget;
-	applet->position        = position;
-	applet->unique_id       = g_strdup (unique_id);
-	applet->destroy_handler =
-			g_signal_connect (panel_widget, "destroy",
-					  G_CALLBACK (panel_destroyed_while_loading),
-					  applet);
+	applet->id          = id;
+	applet->type        = type;
+	applet->toplevel_id = toplevel_id;
+	applet->position    = position;
+	applet->right_stick = right_stick != FALSE;
 
 	panel_applets_to_load = g_slist_prepend (panel_applets_to_load, applet);
 }
 
-static void
-panel_applet_load_list (PanelGConfKeyType type)
-{
-	GConfClient *client;
-	GSList      *id_list, *l;
-	const char  *profile;
-	const char  *temp_key = NULL;
-	
-	client  = panel_gconf_get_client ();
-	profile = panel_gconf_get_profile ();
-
-	if (type == PANEL_GCONF_APPLETS)
-		temp_key = panel_gconf_general_key (profile, "applet_id_list");
-	else
-        	temp_key = panel_gconf_general_key (profile, "object_id_list");
-
-        id_list = gconf_client_get_list (
-			panel_gconf_get_client (), temp_key,
-			GCONF_VALUE_STRING, NULL);
-
-        for (l = id_list; l; l = l->next)
-		panel_applet_load_from_unique_id (type, client, profile, (char *) l->data);
-
-	panel_g_slist_deep_free (id_list);
-}
-
 static int
 panel_applet_compare (const PanelAppletToLoad *a,
 		      const PanelAppletToLoad *b)
 {
-	if (a->panel_widget != b->panel_widget)
-		return a->panel_widget - b->panel_widget;
+	int c;
+
+	if ((c = strcmp (a->toplevel_id, b->toplevel_id)))
+		return c;
 	else
 		return a->position - b->position;
 }
 
 void
-panel_applet_load_applets_from_gconf (void)
+panel_applet_load_queued_applets (void)
 {
-	panel_applet_load_list (PANEL_GCONF_APPLETS);
-	panel_applet_load_list (PANEL_GCONF_OBJECTS);
-
 	if (!panel_applets_to_load)
 		return;
 
@@ -896,130 +748,19 @@ panel_applet_load_applets_from_gconf (void)
 	g_idle_add (panel_applet_load_idle_handler, NULL);
 }
 
-static void
-panel_applet_load_default_applet_for_screen (PanelGConfKeyType  type,
-					     const char        *profile,
-					     const char        *applet_id,
-					     int                screen)
-{
-	GConfClient *client;
-	GError      *error = NULL;
-	GSList      *id_list, *l;
-	const char  *key;
-	char        *new_applet_id;
-	char        *panel_id, *new_panel_id;
-
-	new_applet_id = panel_gconf_load_default_config_for_screen (
-				type, profile, applet_id, screen, &error);
-	if (error) {
-		g_warning ("Could not load default config for applet '%s': '%s'\n",
-			   applet_id, error->message);
-		g_error_free (error);
-		return;
-	}
-
-	client = panel_gconf_get_client ();
-
-	key = panel_gconf_full_key (type, profile, new_applet_id, "panel_id");
-	panel_id = gconf_client_get_string (client, key, NULL);
-	if (!panel_id) {
-		g_printerr (_("No panel_id set for panel object with ID %s\n"), new_applet_id);
-		g_free (new_applet_id);
-		return;
-	}
-
-	new_panel_id = g_strdup_printf ("%s_screen%d", panel_id, screen);
-	gconf_client_set_string (client, key, new_panel_id, NULL);
-	g_free (new_panel_id);
-	g_free (panel_id);
-
-	if (type == PANEL_GCONF_APPLETS)
-		key = panel_gconf_general_key (profile, "applet_id_list");
-	else
-		key = panel_gconf_general_key (profile, "object_id_list");
-
-	id_list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
-
-	for (l = id_list; l; l = l->next)
-		if (!strcmp (new_applet_id, (char *) l->data))
-			break;
-
-	if (!l) {
-		id_list = g_slist_prepend (id_list, new_applet_id);
-		new_applet_id = NULL;
-
-		gconf_client_set_list (client, key, GCONF_VALUE_STRING, id_list, NULL);
-	}
-
-	panel_g_slist_deep_free (id_list);
-	g_free (new_applet_id);
-}
-
-void
-panel_applet_load_defaults_for_screen (PanelGConfKeyType  type,
-				       const char        *profile,
-				       int                screen)
-{
-	GConfClient *client;
-	GSList      *applets, *l;
-	GError      *error = NULL;
-	const char  *subdir = NULL;
-	const char  *schemas_dir = NULL;
-
-	switch (type) {
-	case PANEL_GCONF_APPLETS:
-		subdir = "applets";
-		break;
-	case PANEL_GCONF_OBJECTS:
-		subdir = "objects";
-		break;
-	default:
-		g_assert_not_reached ();
-		break;
-	}
-
-	client = panel_gconf_get_client ();
-
-	/* FIXME: "medium" shouldn't be hardcoded.
-	 */
-	schemas_dir = panel_gconf_sprintf (
-			"/schemas/apps/panel/default_profiles/medium/%s", subdir);
-
-	applets = gconf_client_all_dirs (client, schemas_dir, &error);
-	if (error) {
-		g_warning ("Cannot list default '%s': '%s'\n", subdir, error->message);
-		g_error_free (error);
-		return;
-	}
-
-	for (l = applets; l; l = l->next) {
-		char *applet_id;
-
-		applet_id = g_path_get_basename (l->data);
-
-		panel_applet_load_default_applet_for_screen (	
-				type, profile, applet_id, screen);
-
-		g_free (applet_id);
-		g_free (l->data);
-	}
-
-        g_slist_free (applets);
-}
-
 static G_CONST_RETURN char *
-panel_applet_get_panel_id (AppletInfo *applet)
+panel_applet_get_toplevel_id (AppletInfo *applet)
 {
-	PanelWidget *panel;
+	PanelWidget *panel_widget;
 
 	g_return_val_if_fail (applet != NULL, NULL);
 	g_return_val_if_fail (GTK_IS_WIDGET (applet->widget), NULL);
 
-	panel = PANEL_WIDGET (applet->widget->parent);
-	if (!panel)
+	panel_widget = PANEL_WIDGET (applet->widget->parent);
+	if (!panel_widget)
 		return NULL;
 
-	return panel->unique_id;
+	return panel_profile_get_toplevel_id (panel_widget->toplevel);
 }
 
 static gboolean
@@ -1032,7 +773,7 @@ panel_applet_position_save_timeout (gpointer dummy)
 	for (l = queued_position_saves; l; l = l->next) {
 		AppletInfo *info = l->data;
 
-		panel_applet_save_position (info, info->gconf_key, TRUE);
+		panel_applet_save_position (info, info->id, TRUE);
 	}
 
 	g_slist_free (queued_position_saves);
@@ -1043,14 +784,14 @@ panel_applet_position_save_timeout (gpointer dummy)
 
 void
 panel_applet_save_position (AppletInfo *applet_info,
-			    const char *gconf_key,
+			    const char *id,
 			    gboolean    immediate)
 {
 	PanelGConfKeyType  key_type;
 	GConfClient       *client;
 	const char        *profile;
-	const char        *temp_key;
-	const char        *panel_id;
+	const char        *key;
+	const char        *toplevel_id;
 	gboolean           right_stick;
 	int                position;
 
@@ -1070,125 +811,73 @@ panel_applet_save_position (AppletInfo *applet_info,
 		return;
 	}
 
-	if (!(panel_id = panel_applet_get_panel_id (applet_info)))
+	if (!(toplevel_id = panel_applet_get_toplevel_id (applet_info)))
 		return;
 
 	client  = panel_gconf_get_client ();
-	profile = panel_gconf_get_profile ();
+	profile = panel_profile_get_name ();
 
-	if (applet_info->type == APPLET_BONOBO)
-		key_type = PANEL_GCONF_APPLETS;
-	else
-		key_type = PANEL_GCONF_OBJECTS;
+	key_type = applet_info->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
 
-	temp_key = panel_gconf_full_key (key_type, profile, gconf_key, "panel_id");
-	gconf_client_set_string (client, temp_key, panel_id, NULL);
+	key = panel_gconf_full_key (key_type, profile, id, "toplevel_id");
+	gconf_client_set_string (client, key, toplevel_id, NULL);
 
 	right_stick = panel_is_applet_right_stick (applet_info->widget);
-	temp_key = panel_gconf_full_key (
-			key_type, profile, gconf_key, "panel_right_stick");
-	gconf_client_set_bool (client, temp_key, right_stick, NULL);
+	key = panel_gconf_full_key (
+			key_type, profile, id, "panel_right_stick");
+	gconf_client_set_bool (client, key, right_stick, NULL);
 
 	position = panel_applet_get_position (applet_info);
 	if (right_stick && !PANEL_WIDGET (applet_info->widget->parent)->packed)
 		position = PANEL_WIDGET (applet_info->widget->parent)->size - position;
 
-	temp_key = panel_gconf_full_key (
-			key_type, profile, gconf_key, "position");
-	gconf_client_set_int (client, temp_key, position, NULL);
+	key = panel_gconf_full_key (key_type, profile, id, "position");
+	gconf_client_set_int (client, key, position, NULL);
 }
 
-void
-panel_applet_save_to_gconf (AppletInfo *applet_info)
+const char *
+panel_applet_get_id (AppletInfo *info)
 {
-	PanelGConfKeyType  key_type;
-	GConfClient       *client;
-	const char        *profile;
-	const char        *temp_key;
-	GSList            *id_list, *l;
+	if (!info)
+		return NULL;
 
-	client  = panel_gconf_get_client ();
-	profile = panel_gconf_get_profile ();
-
-	if (applet_info->type == APPLET_BONOBO)
-		temp_key = panel_gconf_general_key (profile, "applet_id_list");
-	else
-		temp_key = panel_gconf_general_key (profile, "object_id_list");
-
-	id_list = gconf_client_get_list (client, temp_key, GCONF_VALUE_STRING, NULL);
-
-	if (!applet_info->gconf_key)
-		applet_info->gconf_key = gconf_unique_key ();
-
-	for (l = id_list; l; l = l->next)
-		if (strcmp (applet_info->gconf_key, (char *) l->data) == 0)
-			break;
-
-	if (!l) {
-		id_list = g_slist_prepend (id_list, g_strdup (applet_info->gconf_key));
-
-		gconf_client_set_list (client, temp_key, GCONF_VALUE_STRING, id_list, NULL);
-	}
-
-	panel_g_slist_deep_free (id_list);
-
-	if (applet_info->type == APPLET_BONOBO)
-		key_type = PANEL_GCONF_APPLETS;
-	else
-		key_type = PANEL_GCONF_OBJECTS;
-
-	temp_key = panel_gconf_full_key (
-			key_type, profile, applet_info->gconf_key, "object_type");
-	gconf_client_set_string (
-		client, temp_key,
-		gconf_enum_to_string (object_type_enum_map, applet_info->type),
-		NULL);
-
-	panel_applet_save_position (applet_info, applet_info->gconf_key, TRUE);
-
-	switch (applet_info->type) {
-	case APPLET_BONOBO:
-		panel_applet_frame_save_to_gconf (PANEL_APPLET_FRAME (applet_info->widget),
-						  applet_info->gconf_key);
-		break;
-	case APPLET_DRAWER:
-		drawer_save_to_gconf ((Drawer *) applet_info->data,
-				      applet_info->gconf_key);
-		break;
-	case APPLET_MENU:
-		menu_save_to_gconf ((Menu *) applet_info->data,
-				    applet_info->gconf_key);
-		break;
-	case APPLET_LAUNCHER:
-		launcher_save_to_gconf ((Launcher *) applet_info->data,
-					applet_info->gconf_key);
-		break;
-	case APPLET_ACTION:
-	case APPLET_LOGOUT:
-	case APPLET_LOCK:
-		panel_action_button_save_to_gconf (
-			PANEL_ACTION_BUTTON (applet_info->widget),
-			applet_info->gconf_key);
-		break;
-	default:
-		break;
-	}
+	return info->id;
 }
 
 AppletInfo *
-panel_applet_register (GtkWidget      *applet,
-		       gpointer        data,
-		       GDestroyNotify  data_destroy,
-		       PanelWidget    *panel,
-		       gint            pos,
-		       gboolean        exactpos,
-		       AppletType      type,
-		       const char     *gconf_key)
+panel_applet_get_by_id (const char *id)
+{
+	GSList *l;
+
+	for (l = registered_applets; l; l = l->next) {
+		AppletInfo *info = l->data;
+
+		if (!strcmp (info->id, id))
+			return info;
+	}
+
+	return NULL;
+}
+
+GSList *
+panel_applet_list_applets (void)
+{
+	return registered_applets;
+}
+
+AppletInfo *
+panel_applet_register (GtkWidget       *applet,
+		       gpointer         data,
+		       GDestroyNotify   data_destroy,
+		       PanelWidget     *panel,
+		       gint             pos,
+		       gboolean         exactpos,
+		       PanelObjectType  type,
+		       const char      *id)
 {
 	AppletInfo *info;
 	int newpos;
 	gboolean insert_at_pos;
-	gboolean expand_major = FALSE, expand_minor = FALSE;
 	
 	g_return_val_if_fail (applet != NULL && panel != NULL, NULL);
 
@@ -1199,21 +888,20 @@ panel_applet_register (GtkWidget      *applet,
 					  GDK_POINTER_MOTION_HINT_MASK));
 
 	info = g_new0 (AppletInfo, 1);
-	info->applet_id = applet_count;
 	info->type = type;
 	info->widget = applet;
 	info->menu = NULL;
-	info->menu_age = 0;
 	info->data = data;
 	info->data_destroy = data_destroy;
 	info->user_menu = NULL;
 
 	g_object_set_data (G_OBJECT (applet), "applet_info", info);
 
-	if (type == APPLET_DRAWER) {
+	if (type == PANEL_OBJECT_DRAWER) {
 		Drawer *drawer = data;
-		PanelWidget *assoc_panel =
-			PANEL_WIDGET (BASEP_WIDGET (drawer->drawer)->panel);
+		PanelWidget *assoc_panel;
+
+		assoc_panel = panel_toplevel_get_panel_widget (drawer->toplevel);
 
 		g_object_set_data (G_OBJECT (applet),
 				   PANEL_APPLET_ASSOC_PANEL_KEY, assoc_panel);
@@ -1225,17 +913,7 @@ panel_applet_register (GtkWidget      *applet,
 	g_object_set_data (G_OBJECT (applet),
 			   PANEL_APPLET_FORBIDDEN_PANELS, NULL);
 
-	if (type == APPLET_BONOBO)
-		panel_applet_frame_get_expand_flags (PANEL_APPLET_FRAME (applet),
-						     &expand_major,
-						     &expand_minor);
-	
-	applets = g_slist_append (applets, info);
-
-	applet_count++;
-
-	/*we will need to save this applet's config now*/
-	applets_to_sync = TRUE;
+	registered_applets = g_slist_append (registered_applets, info);
 
 	/*add at the beginning if pos == -1*/
 	if (pos >= 0) {
@@ -1249,18 +927,16 @@ panel_applet_register (GtkWidget      *applet,
 	if (exactpos)
 		insert_at_pos = TRUE;
 
-	if (panel_widget_add (panel, applet, newpos,
-			      insert_at_pos, expand_major, expand_minor) == -1) {
+	if (panel_widget_add (panel, applet, newpos, insert_at_pos) == -1) {
 		GSList *l;
 
 		for (l = panels; l; l = l->next)
-			if (panel_widget_add (panel, applet, 0, TRUE,
-					      expand_major, expand_minor) != -1)
+			if (panel_widget_add (panel, applet, 0, TRUE) != -1)
 				break;
 
 		if (!l) {
-			panel_applet_clean (info, TRUE);
 			g_warning (_("Can't find an empty spot"));
+			panel_profile_delete_object (info);
 			return NULL;
 		}
 
@@ -1286,14 +962,13 @@ panel_applet_register (GtkWidget      *applet,
 
 	orientation_change (info, panel);
 	size_change (info, panel);
+#ifdef FIXME_FOR_NEW_CONFIG
 	back_change (info, panel);
+#endif
 
-	if (gconf_key)
-		info->gconf_key = g_strdup (gconf_key);
+	if (id) info->id = g_strdup (id);
 
-	panel_applet_save_to_gconf (info);
-
-	if (type != APPLET_BONOBO)
+	if (type != PANEL_OBJECT_BONOBO)
 		gtk_widget_grab_focus (applet);
 	else
 		gtk_widget_child_focus (applet, GTK_DIR_TAB_FORWARD);
