@@ -2,6 +2,7 @@
  * panel-background-monitor.c:
  *
  * Copyright (C) 2001, 2002 Ian McKellar <yakk@yakk.net>
+ *                     2002 Sun Microsystems, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -257,6 +258,7 @@ panel_background_monitor_tile_background (PanelBackgroundMonitor *monitor,
 					  int                     height)
 {
 	GdkPixbuf *retval;
+	ArtIRect   rect;
 	int        tilewidth, tileheight;
 
 	retval = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, width, height);
@@ -264,35 +266,15 @@ panel_background_monitor_tile_background (PanelBackgroundMonitor *monitor,
 	tilewidth  = gdk_pixbuf_get_width (monitor->gdkpixbuf);
 	tileheight = gdk_pixbuf_get_height (monitor->gdkpixbuf);
 
-	if (tilewidth == 1 && tileheight == 1) {
-		guchar  *pixels;
-		int      n_channels;
-		guint32  pixel = 0;
+	rect.x0 = 0;
+	rect.y0 = 0;
+	rect.x1 = width;
+	rect.y1 = height;
 
-		n_channels = gdk_pixbuf_get_n_channels (monitor->gdkpixbuf);
-		pixels     = gdk_pixbuf_get_pixels (monitor->gdkpixbuf);
-
-		if (pixels) {
-			if (n_channels == 4)
-				pixel = ((guint32 *) pixels) [0];
-			else if (n_channels == 3)
-				pixel = pixels [0] << 24 | pixels [1] << 16 | pixels [2] << 8;
-		}
-
-		gdk_pixbuf_fill (retval, pixel);
-	} else {
-		ArtIRect rect;
-
-		rect.x0 = 0;
-		rect.y0 = 0;
-		rect.x1 = width;
-		rect.y1 = height;
-
-		panel_gdk_pixbuf_draw_to_pixbuf_tiled (
-			monitor->gdkpixbuf, retval,
-			rect, tilewidth, tileheight,
-			0, 0, 255, GDK_INTERP_NEAREST);
-	}
+	panel_gdk_pixbuf_draw_to_pixbuf_tiled (
+		monitor->gdkpixbuf, retval,
+		rect, tilewidth, tileheight,
+		0, 0, 255, GDK_INTERP_NEAREST);
 
 	return retval;
 }
@@ -332,6 +314,7 @@ panel_background_monitor_setup_pixbuf (PanelBackgroundMonitor *monitor)
 
 		tiled = panel_background_monitor_tile_background (
 						monitor, rwidth, rheight);
+
 		g_object_unref (monitor->gdkpixbuf);
 		monitor->gdkpixbuf = tiled;
 
