@@ -47,6 +47,7 @@ show_uri (const char *uri, const char *mime_type, GdkScreen *screen,
 	GString                 *str;
 	char                    *cmd   = NULL;
 	char                    *path;
+	char			*quoted;
 	gboolean                 ret   = TRUE;
 	
 	app = gnome_vfs_mime_get_default_application (mime_type);
@@ -71,8 +72,11 @@ show_uri (const char *uri, const char *mime_type, GdkScreen *screen,
 	case GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS:
 		path = gnome_vfs_get_local_path_from_uri (uri);
 		if (path != NULL) {
-			g_string_append_printf (str, " %s", path);
+			quoted = g_shell_quote (path);
 			g_free (path);
+
+			g_string_append_printf (str, " %s", quoted);
+			g_free (quoted);
 		} else {
 			gnome_vfs_mime_application_free (app);
 			g_string_free (str, TRUE);
@@ -84,18 +88,25 @@ show_uri (const char *uri, const char *mime_type, GdkScreen *screen,
 		break;
 
 	case GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS:
-		g_string_append_printf (str, " %s", uri);
+		quoted = g_shell_quote (uri);
+		g_string_append_printf (str, " %s", quoted);
+		g_free (quoted);
 		break;
 
 	case GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES:
 		path = gnome_vfs_get_local_path_from_uri (uri);
 
-		if (path != NULL)
-			g_string_append_printf (str, " %s", path);
-		else
-			g_string_append_printf (str, " %s", uri);
+		if (path != NULL) {
+			quoted = g_shell_quote (path);
+			g_string_append_printf (str, " %s", quoted);
+			g_free (quoted);
+			g_free (path);
+		} else {
+			quoted = g_shell_quote (uri);
+			g_string_append_printf (str, " %s", quoted);
+			g_free (quoted);
+		}
 
-		g_free (path);
 		break;
 	}
 
@@ -157,6 +168,9 @@ panel_recent_append_documents_menu (GtkWidget *top_menu)
 	menu = panel_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu);
 
+	g_signal_connect (G_OBJECT (menu), "button_press_event",
+			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+
 	gtk_menu_shell_append (GTK_MENU_SHELL (top_menu), menu_item);
 	gtk_widget_show_all (menu_item);
 	
