@@ -32,24 +32,18 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include <libwnck/screen.h>
-#include <libwnck/workspace.h>
-
 #include "panel-util.h"
 
 #include "applet.h"
 #include "nothing.h"
-#include "basep-widget.h"
-#include "foobar-widget.h"
 #include "panel.h"
+#include "panel-a11y.h"
 #include "egg-screen-exec.h"
 #include "egg-screen-url.h"
 #include "egg-screen-help.h"
-
-extern GlobalConfig global_config;
-
-extern GSList *applets;
-extern GSList *panels;
+#include "xstuff.h"
+#include "panel-globals.h"
+#include "launcher.h"
 
 GdkScreen *
 panel_screen_from_number (int screen)
@@ -65,18 +59,9 @@ panel_ditem_launch (const GnomeDesktopItem       *item,
 		    GdkScreen                    *screen,
 		    GError                      **error)
 {
-	WnckScreen *wnck_screen = NULL;
-	int         workspace;
+	int workspace;
 
-	if (screen)
-		wnck_screen = wnck_screen_get (
-				gdk_screen_get_number (screen));
-
-	if (!wnck_screen)
-		wnck_screen = wnck_screen_get_default ();
-
-	workspace = wnck_workspace_get_number (
-			wnck_screen_get_active_workspace (wnck_screen));
+	workspace = xstuff_get_current_workspace (screen);
 
 	return gnome_desktop_item_launch_on_screen (
 			item, file_list, flags, screen, workspace, error);
@@ -251,7 +236,7 @@ create_text_entry(GtkWidget *table,
 			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
 			 GTK_FILL | GTK_SHRINK,
 			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	panel_set_atk_relation (entry, GTK_LABEL (wlabel));
+	panel_a11y_set_atk_relation (entry, GTK_LABEL (wlabel));
 
 	if(func) {
 		g_object_set_data (G_OBJECT (t), "update_function", func);
@@ -290,7 +275,7 @@ create_icon_entry(GtkWidget *table,
 	if (text != NULL)
 		gnome_icon_entry_set_filename (GNOME_ICON_ENTRY(entry), text);
 
-	panel_set_atk_relation (entry, GTK_LABEL (wlabel));
+	panel_a11y_set_atk_relation (entry, GTK_LABEL (wlabel));
 	gtk_table_attach(GTK_TABLE(table), entry,
 			 cols, cole, 1, 2,
 			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
@@ -625,38 +610,6 @@ panel_set_frame_colors (PanelWidget *panel, GtkWidget *frame,
 	}
 }
 
-gboolean
-panel_parse_accelerator (GlobalConfigKey *key)
-{
-	g_return_val_if_fail (key != NULL, FALSE);
-	
-	key->keysym = 0;
-	key->state = 0;
-
-	if (key->str == NULL ||
-	    key->str[0] == '\0' ||
-	    strcmp (key->str, "Disabled") == 0 ||
-	    strcmp (key->str, _("Disabled")) == 0)
-		return FALSE;
-
-	gtk_accelerator_parse (key->str, &key->keysym, &key->state);
-
-	if (key->keysym == 0)
-		return FALSE;
-
-	return TRUE;
-}
-
-char *
-convert_keysym_state_to_string(guint keysym,
-			       GdkModifierType state)
-{
-	if (keysym == 0)
-		return g_strdup (_("Disabled"));
-
-	return gtk_accelerator_name (keysym, state);
-}
-
 static GtkWidget *
 panel_dialog (GdkScreen  *screen,
 	      int         type,
@@ -773,13 +726,15 @@ is_ext2 (const char *file,
 }
 
 int
-panel_find_applet (GtkWidget *widget)
+panel_find_applet_index (GtkWidget *widget)
 {
-	int i;
-	GSList *li;
+	GSList *applet_list, *l;
+	int     i;
 
-	for (i = 0, li = applets; li != NULL; i++, li = li->next) {
-		AppletInfo *info = li->data;
+	applet_list = panel_applet_list_applets ();
+
+	for (i = 0, l = applet_list; l; i++, l = l->next) {
+		AppletInfo *info = l->data;
 
 		if (info->widget == widget)
 			return i;
@@ -1075,11 +1030,8 @@ stretch_widget_realize (GtkWidget *widget)
 	GtkWidget     *toplevel;
 
 	eventwin = g_object_get_data (G_OBJECT (widget), "StrechEventWindow");
-	if (eventwin != NULL) {
-		gdk_window_set_user_data (eventwin, NULL);
-		g_object_set_data (G_OBJECT (widget), "StrechEventWindow", NULL);
+	if (eventwin != NULL)
 		gdk_window_destroy (eventwin);
-	}
 
 	toplevel = stretch_widget_calc_geometry (widget, &x, &y, &w, &h);
 	if (!toplevel)
@@ -1118,7 +1070,6 @@ stretch_widget_unrealize (GtkWidget *widget)
 	if (eventwin == NULL)
 		return;
 
-	gdk_window_set_user_data (eventwin, NULL);
 	gdk_window_destroy (eventwin);
 	g_object_set_data (G_OBJECT (widget),
 			   "StrechEventWindow",
@@ -1489,3 +1440,75 @@ panel_lock_screen (GdkScreen *screen)
 				    _("<b>Cannot execute xscreensaver</b>\n\n"
 				    "Details: xscreensaver-command not found"));
 }
+
+
+char *
+panel_make_full_path (const char *dir,
+		      const char *filename)
+{
+	char *retval;
+	char *freeme = NULL;
+
+	g_return_val_if_fail (filename != NULL, NULL);
+
+	if (!dir) {
+		freeme = gnome_util_home_file (PANEL_LAUNCHERS_PATH);
+		dir = freeme;
+	}
+
+	/* Make sure the launcher directory exists */
+	if (!g_file_test (dir, G_FILE_TEST_EXISTS))
+		panel_ensure_dir (dir);
+
+	retval = g_build_filename (dir, filename, NULL);
+
+	g_free (freeme);
+
+	return retval;
+}
+
+char *
+panel_make_unique_path (const char *dir,
+			const char *suffix)
+{
+#define NUM_OF_WORDS 12
+	char *words[] = {
+		"foo",
+		"bar",
+		"blah",
+		"gegl",
+		"frobate",
+		"hadjaha",
+		"greasy",
+		"hammer",
+		"eek",
+		"larry",
+		"curly",
+		"moe",
+		NULL};
+	char     *retval = NULL;
+	gboolean  exists = TRUE;
+
+	while (exists) {
+		char *filename;
+		int   rnd;
+		int   word;
+
+		rnd = rand ();
+		word = rand () % NUM_OF_WORDS;
+
+		filename = g_strdup_printf ("%s-%010x%s",
+					    words [word],
+					    (guint) rnd,
+					    suffix);
+
+		g_free (retval);
+		retval = panel_make_full_path (dir, filename);
+		exists = g_file_test (retval, G_FILE_TEST_EXISTS);
+		g_free (filename);
+	}
+
+	return retval;
+
+#undef NUM_OF_WORDS
+}
