@@ -76,11 +76,6 @@ void		panel_set_frame_colors	(PanelWidget *panel,
 					 GtkWidget *but3,
 					 GtkWidget *but4);
 
-gboolean        panel_parse_accelerator (GlobalConfigKey *key);
-
-char *		convert_keysym_state_to_string (guint keysym,
-						GdkModifierType state);
-
 GtkWidget      *panel_error_dialog      (GdkScreen  *screen,
 					 const char *class,
 					 const char *format,
@@ -96,7 +91,7 @@ gboolean	is_ext2			(const char *file,
 					 const char *ext1,
 					 const char *ext2);
 
-int		panel_find_applet	(GtkWidget *widget);
+int		panel_find_applet_index	(GtkWidget *widget);
 
 int		get_requisition_width	(GtkWidget *widget);
 int		get_requisition_height	(GtkWidget *widget);
@@ -167,6 +162,10 @@ void panel_set_atk_relation  (GtkWidget *widget,
 
 GdkPixbuf *	missing_pixbuf		(int size);
 
+char *panel_make_full_path   (const char *dir,
+			      const char *filename);
+char *panel_make_unique_path (const char *dir,
+			      const char *suffix);
 
 G_END_DECLS
 
